@@ -329,7 +329,7 @@ class fabba_model(Aggregation2D):
     
     >>> fabba = model(tol=0.1, alpha=0.5, sorting='lexi', scl=1, verbose=1, max_len=np.inf, string_form=True) 
     >>> print(fabba)
-    fABBA(tol=0.1, alpha=0.5, sorting='2-norm', scl=1, verbose=1, max_len=inf, string_form=True)
+    fABBA(tol=0.1, alpha=0.5, sorting='lexi', scl=1, verbose=1, max_len=inf, string_form=True)
     >>> symbolic_tsf = fabba.fit_transform(x)
     >>> inverse_ts = fabba.inverse_transform(symbolic_tsf, x[0])
     
@@ -533,9 +533,7 @@ class fabba_model(Aggregation2D):
             npieces[:,1] = npieces[:,1] / self._std[1]
         
         if self.sorting in ["lexi", "2-norm", "1-norm"]:
-            warnings.warn(f"Pass {self.sorting} as keyword args. From the next version "
-                  f"passing these as positional arguments "
-                  "will result in an error. Additionally, cython implementation will be impossible for this sorting.", 
+            warnings.warn(f"Pass {self.sorting} as keyword args. From the next version ", 
                           FutureWarning)
             splist, labels = self.aggregate(npieces)
         else:
